import{M as p,aD as d,c as f,l,S as v,J as t,w as a,O as _,Q as g,X as V,_ as r,$ as s,P as h,m as b,Y as B}from"./index-966f7f24.js";import{V as S}from"./VToolbar-4fa32985.js";import{V as T}from"./VDivider-b2a222eb.js";import{a as $,V as n}from"./VTabs-03587c0f.js";import"./VImg-be0bd66e.js";import"./index-6b660d06.js";import"./VBtn-3f9939c9.js";import"./forwardRefs-efacd11c.js";import"./VProgressCircular-22d71813.js";import"./resizeObserver-b8ff4a76.js";import"./VSlideGroup-308a2eac.js";const k=g("div",{style:{height:"15px"}},null,-1),Q=p({__name:"Settings",setup(w){const i=d(),c=f(()=>{var e,o;return(e=i.currentRoute.value.name)!=null&&e.toString().includes("forecast")?"forecast":(o=i.currentRoute.value.name)!=null&&o.toString().includes("core")?"core":"devices"});return(e,o)=>{const u=V("router-view");return l(),v("div",null,[t(S,{color:"transparent",title:_(h)("bp4")?e.$t("app.settings"):""},{append:a(()=>[t($,{"model-value":c.value,"align-tabs":"end",height:"100%"},{default:a(()=>[t(n,{value:"devices",to:{name:"devicessettings"}},{default:a(()=>[r(s(e.$t("settings.devices")),1)]),_:1}),t(n,{value:"forecast",to:{name:"forecastsettings"}},{default:a(()=>[r(s(e.$t("settings.forecast")),1)]),_:1}),t(n,{value:"core",to:{name:"coresettings"}},{default:a(()=>[r(s(e.$t("settings.core")),1)]),_:1})]),_:1},8,["model-value"])]),_:1},8,["title"]),t(T),k,t(u,null,{default:a(({Component:m})=>[(l(),b(B(m)))]),_:1})])}}});export{Q as default};
