import{a as g,i as b,j as S,V as A,x as k,m as H,y as K,b as Q,I as $,N as q,O as G,c as U,p as W,d as X,o as Y,R as Z,u as ee,r as ae,k as te,z as ne,f as de,J as ie,P as le,Q as se,g as ce,v as re,B as ue,L as ve,w as oe}from"./VImg-be0bd66e.js";import{z as f,I as me,J as n,p as x,af as u,K as p,y as ye,B as ke,c as h,ai as ge,aj as be}from"./index-966f7f24.js";import{c as I,V as P}from"./VAvatar-0bab3ea1.js";const fe=f()({name:"VCardActions",props:g(),setup(e,i){let{slots:t}=i;return me({VBtn:{slim:!0,variant:"text"}}),b(()=>{var a;return n("div",{class:["v-card-actions",e.class],style:e.style},[(a=t.default)==null?void 0:a.call(t)])}),{}}}),Ie=I("v-card-subtitle"),Ve=I("v-card-title"),Ce=x({appendAvatar:String,appendIcon:u,prependAvatar:String,prependIcon:u,subtitle:[String,Number],title:[String,Number],...g(),...S()},"VCardItem"),Ae=f()({name:"VCardItem",props:Ce(),setup(e,i){let{slots:t}=i;return b(()=>{var s;const a=!!(e.prependAvatar||e.prependIcon),v=!!(a||t.prepend),l=!!(e.appendAvatar||e.appendIcon),o=!!(l||t.append),m=!!(e.title!=null||t.title),y=!!(e.subtitle!=null||t.subtitle);return n("div",{class:["v-card-item",e.class],style:e.style},[v&&n("div",{key:"prepend",class:"v-card-item__prepend"},[t.prepend?n(k,{key:"prepend-defaults",disabled:!a,defaults:{VAvatar:{density:e.density,image:e.prependAvatar},VIcon:{density:e.density,icon:e.prependIcon}}},t.prepend):n(p,null,[e.prependAvatar&&n(P,{key:"prepend-avatar",density:e.density,image:e.prependAvatar},null),e.prependIcon&&n(A,{key:"prepend-icon",density:e.density,icon:e.prependIcon},null)])]),n("div",{class:"v-card-item__content"},[m&&n(Ve,{key:"title"},{default:()=>{var d;return[((d=t.title)==null?void 0:d.call(t))??e.title]}}),y&&n(Ie,{key:"subtitle"},{default:()=>{var d;return[((d=t.subtitle)==null?void 0:d.call(t))??e.subtitle]}}),(s=t.default)==null?void 0:s.call(t)]),o&&n("div",{key:"append",class:"v-card-item__append"},[t.append?n(k,{key:"append-defaults",disabled:!l,defaults:{VAvatar:{density:e.density,image:e.appendAvatar},VIcon:{density:e.density,icon:e.appendIcon}}},t.append):n(p,null,[e.appendIcon&&n(A,{key:"append-icon",density:e.density,icon:e.appendIcon},null),e.appendAvatar&&n(P,{key:"append-avatar",density:e.density,image:e.appendAvatar},null)])])])}),{}}}),pe=I("v-card-text"),he=x({appendAvatar:String,appendIcon:u,disabled:Boolean,flat:Boolean,hover:Boolean,image:String,link:{type:Boolean,default:void 0},prependAvatar:String,prependIcon:u,ripple:{type:[Boolean,Object],default:!0},subtitle:[String,Number],text:[String,Number],title:[String,Number],...H(),...g(),...S(),...K(),...Q(),...$(),...q(),...G(),...U(),...W(),...X(),...ye(),...Y({variant:"elevated"})},"VCard"),Be=f()({name:"VCard",directives:{Ripple:Z},props:he(),setup(e,i){let{attrs:t,slots:a}=i;const{themeClasses:v}=ke(e),{borderClasses:l}=ee(e),{colorClasses:o,colorStyles:m,variantClasses:y}=ae(e),{densityClasses:s}=te(e),{dimensionStyles:d}=ne(e),{elevationClasses:B}=de(e),{loaderClasses:L}=ie(e),{locationStyles:T}=le(e),{positionClasses:D}=se(e),{roundedClasses:_}=ce(e),c=re(e,t),N=h(()=>e.link!==!1&&c.isLink.value),r=h(()=>!e.disabled&&e.link!==!1&&(e.link||c.isClickable.value));return b(()=>{const R=N.value?"a":e.tag,j=!!(a.title||e.title!=null),F=!!(a.subtitle||e.subtitle!=null),O=j||F,w=!!(a.append||e.appendAvatar||e.appendIcon),z=!!(a.prepend||e.prependAvatar||e.prependIcon),E=!!(a.image||e.image),J=O||z||w,M=!!(a.text||e.text!=null);return ge(n(R,{class:["v-card",{"v-card--disabled":e.disabled,"v-card--flat":e.flat,"v-card--hover":e.hover&&!(e.disabled||e.flat),"v-card--link":r.value},v.value,l.value,o.value,s.value,B.value,L.value,D.value,_.value,y.value,e.class],style:[m.value,d.value,T.value,e.style],href:c.href.value,onClick:r.value&&c.navigate,tabindex:e.disabled?-1:void 0},{default:()=>{var V;return[E&&n("div",{key:"image",class:"v-card__image"},[a.image?n(k,{key:"image-defaults",disabled:!e.image,defaults:{VImg:{cover:!0,src:e.image}}},a.image):n(ue,{key:"image-img",cover:!0,src:e.image},null)]),n(ve,{name:"v-card",active:!!e.loading,color:typeof e.loading=="boolean"?void 0:e.loading},{default:a.loader}),J&&n(Ae,{key:"item",prependAvatar:e.prependAvatar,prependIcon:e.prependIcon,title:e.title,subtitle:e.subtitle,appendAvatar:e.appendAvatar,appendIcon:e.appendIcon},{default:a.item,prepend:a.prepend,title:a.title,subtitle:a.subtitle,append:a.append}),M&&n(pe,{key:"text"},{default:()=>{var C;return[((C=a.text)==null?void 0:C.call(a))??e.text]}}),(V=a.default)==null?void 0:V.call(a),a.actions&&n(fe,null,{default:a.actions}),oe(r.value,"v-card")]}}),[[be("ripple"),r.value&&e.ripple]])}),{}}});export{Ve as V,pe as a,Be as b,fe as c,Ae as d};
