import{_ as e}from"./_plugin-vue_export-helper-c27b6911.js";import{l as t,S as s}from"./index-966f7f24.js";const n={},r={class:"m-4"};function o(a,c){return t(),s("p",r," General settings for Energy Assistant are not yet implement in the UI. Please edit energy_assistant.yaml. ")}const l=e(n,[["render",o]]);export{l as default};
