import{a as i,j as g,c as f,q as y,d as V,o as k,r as P,k as S,g as C,s as z,i as h,B as A,V as I,x,w as B}from"./VImg-be0bd66e.js";import{z as o,aS as R,aR as D,a9 as T,p as F,af as _,y as j,B as q,J as l}from"./index-966f7f24.js";function O(a){let r=arguments.length>1&&arguments[1]!==void 0?arguments[1]:"div",s=arguments.length>2?arguments[2]:void 0;return o()({name:s??R(D(a.replace(/__/g,"-"))),props:{tag:{type:String,default:r},...i()},setup(e,u){let{slots:t}=u;return()=>{var n;return T(e.tag,{class:[a,e.class],style:e.style},(n=t.default)==null?void 0:n.call(t))}}})}const w=F({start:Boolean,end:Boolean,icon:_,image:String,text:String,...i(),...g(),...f(),...y(),...V(),...j(),...k({variant:"flat"})},"VAvatar"),$=o()({name:"VAvatar",props:w(),setup(a,r){let{slots:s}=r;const{themeClasses:e}=q(a),{colorClasses:u,colorStyles:t,variantClasses:n}=P(a),{densityClasses:c}=S(a),{roundedClasses:m}=C(a),{sizeClasses:v,sizeStyles:d}=z(a);return h(()=>l(a.tag,{class:["v-avatar",{"v-avatar--start":a.start,"v-avatar--end":a.end},e.value,u.value,c.value,m.value,v.value,n.value,a.class],style:[t.value,d.value,a.style]},{default:()=>[s.default?l(x,{key:"content-defaults",defaults:{VImg:{cover:!0,image:a.image},VIcon:{icon:a.icon}}},{default:()=>[s.default()]}):a.image?l(A,{key:"image",src:a.image,alt:"",cover:!0},null):a.icon?l(I,{key:"icon",icon:a.icon},null):a.text,B(!1,"v-avatar")]})),{}}});export{$ as V,O as c};
