if(!self.define){let s,e={};const l=(l,r)=>(l=new URL(l+".js",r).href,e[l]||new Promise((e=>{if("document"in self){const s=document.createElement("script");s.src=l,s.onload=e,document.head.appendChild(s)}else s=l,importScripts(l),e()})).then((()=>{let s=e[l];if(!s)throw new Error(`Module ${l} didn’t register its module`);return s})));self.define=(r,i)=>{const n=s||("document"in self?document.currentScript.src:"")||location.href;if(e[n])return;let u={};const a=s=>l(s,n),o={module:{uri:n},exports:u,require:a};e[n]=Promise.all(r.map((s=>o[s]||a(s)))).then((s=>(i(...s),u)))}}define(["./workbox-27b29e6f"],(function(s){"use strict";self.addEventListener("message",(s=>{s.data&&"SKIP_WAITING"===s.data.type&&self.skipWaiting()})),s.precacheAndRoute([{url:"assets/_plugin-vue_export-helper-c27b6911.js",revision:null},{url:"assets/CoreConfigs-46ca0007.js",revision:null},{url:"assets/Default-294d6b2c.css",revision:null},{url:"assets/Default-b6fd0f2a.js",revision:null},{url:"assets/Devices-9b0e6e3c.css",revision:null},{url:"assets/Devices-dbda5a05.js",revision:null},{url:"assets/Forecast-89ccd097.js",revision:null},{url:"assets/Forecast-a7daefc9.js",revision:null},{url:"assets/forwardRefs-efacd11c.js",revision:null},{url:"assets/Home-53635917.js",revision:null},{url:"assets/index-13e806b9.css",revision:null},{url:"assets/index-6b660d06.js",revision:null},{url:"assets/index-966f7f24.js",revision:null},{url:"assets/index-e716a86a.js",revision:null},{url:"assets/PowerFlowCard-634571d6.js",revision:null},{url:"assets/PowerFlowCard-b6c1b29b.css",revision:null},{url:"assets/RawData-5204ec57.js",revision:null},{url:"assets/RawData-6458b361.css",revision:null},{url:"assets/resizeObserver-b8ff4a76.js",revision:null},{url:"assets/scopeId-70efedda.js",revision:null},{url:"assets/SessionLog-c795c820.css",revision:null},{url:"assets/SessionLog-db082854.js",revision:null},{url:"assets/Settings-81f528e4.js",revision:null},{url:"assets/Statistics-4a7ad817.js",revision:null},{url:"assets/utils-6f3c77d7.js",revision:null},{url:"assets/VAvatar-0bab3ea1.js",revision:null},{url:"assets/VAvatar-f1503efb.css",revision:null},{url:"assets/VBtn-3f9939c9.js",revision:null},{url:"assets/VBtn-8e3756ee.css",revision:null},{url:"assets/VCard-b8e0937b.css",revision:null},{url:"assets/VCard-f534a22a.js",revision:null},{url:"assets/VDivider-0f172ac3.css",revision:null},{url:"assets/VDivider-b2a222eb.js",revision:null},{url:"assets/VImg-12742cbb.css",revision:null},{url:"assets/VImg-be0bd66e.js",revision:null},{url:"assets/VList-332b5518.js",revision:null},{url:"assets/VList-ff4312e7.css",revision:null},{url:"assets/VOverlay-176f17d1.css",revision:null},{url:"assets/VOverlay-aba1d54e.js",revision:null},{url:"assets/VProgressCircular-22d71813.js",revision:null},{url:"assets/VProgressCircular-4a58d9a5.css",revision:null},{url:"assets/VSelect-10a0958b.css",revision:null},{url:"assets/VSelect-4ce7e6cc.js",revision:null},{url:"assets/VSlideGroup-308a2eac.js",revision:null},{url:"assets/VSlideGroup-d1b6ec2a.css",revision:null},{url:"assets/VTable-9c8ce44e.css",revision:null},{url:"assets/VTable-b03b9a91.js",revision:null},{url:"assets/VTabs-03587c0f.js",revision:null},{url:"assets/VTabs-537e6c44.css",revision:null},{url:"assets/VTextField-8c499a00.css",revision:null},{url:"assets/VTextField-bddeb52f.js",revision:null},{url:"assets/VToolbar-4fa32985.js",revision:null},{url:"assets/VToolbar-93f23da1.css",revision:null},{url:"assets/workbox-window.prod.es5-a7b12eab.js",revision:null},{url:"index.html",revision:"6e31c9736143ab4cf26d6c2860ab79dd"},{url:"robots.txt",revision:"f77c87f977e0fcce05a6df46c885a129"},{url:"apple-touch-icon.png",revision:"ec84610d7d85b67822bcb8a7f5114354"},{url:"pwa-192x192.png",revision:"568e4ca3a35484f7b1cd02882e9e8ac0"},{url:"pwa-512x512.png",revision:"1e5320b35c3f539c43a9132b901bb0e9"},{url:"manifest.webmanifest",revision:"14575172cc64b2172ce0f6fac9b45006"}],{}),s.cleanupOutdatedCaches(),s.registerRoute(new s.NavigationRoute(s.createHandlerBoundToURL("index.html")))}));
