import{a as c,n as v,i as d}from"./VImg-be0bd66e.js";import{p as m,y as h,z as u,B as g,D as y,c as C,b as r,J as V}from"./index-966f7f24.js";const f=m({color:String,inset:Boolean,length:[Number,String],thickness:[Number,String],vertical:Boolean,...c(),...h()},"VDivider"),D=u()({name:"VDivider",props:f(),setup(e,a){let{attrs:t}=a;const{themeClasses:o}=g(e),{textColorClasses:s,textColorStyles:n}=v(y(e,"color")),l=C(()=>{const i={};return e.length&&(i[e.vertical?"maxHeight":"maxWidth"]=r(e.length)),e.thickness&&(i[e.vertical?"borderRightWidth":"borderTopWidth"]=r(e.thickness)),i});return d(()=>V("hr",{class:[{"v-divider":!0,"v-divider--inset":e.inset,"v-divider--vertical":e.vertical},o.value,s.value,e.class],style:[l.value,n.value,e.style],"aria-orientation":!t.role||t.role==="separator"?e.vertical?"vertical":"horizontal":void 0,role:`${t.role||"separator"}`},null)),{}}});export{D as V};
