import{a as m,j as b,d,k as h,i as v}from"./VImg-be0bd66e.js";import{p as f,y as c,z as u,B as g,J as t,b as T}from"./index-966f7f24.js";const x=f({fixedHeader:Boolean,fixedFooter:Boolean,height:[Number,String],hover:Boolean,...m(),...b(),...d(),...c()},"VTable"),p=u()({name:"VTable",props:x(),setup(a,r){let{slots:e,emit:y}=r;const{themeClasses:i}=g(a),{densityClasses:n}=h(a);return v(()=>t(a.tag,{class:["v-table",{"v-table--fixed-height":!!a.height,"v-table--fixed-header":a.fixedHeader,"v-table--fixed-footer":a.fixedFooter,"v-table--has-top":!!e.top,"v-table--has-bottom":!!e.bottom,"v-table--hover":a.hover},i.value,n.value,a.class],style:a.style},{default:()=>{var o,l,s;return[(o=e.top)==null?void 0:o.call(e),e.default?t("div",{class:"v-table__wrapper",style:{height:T(a.height)}},[t("table",null,[e.default()])]):(l=e.wrapper)==null?void 0:l.call(e),(s=e.bottom)==null?void 0:s.call(e)]}})),{}}});export{p as V};
